.. title:: evidence

.. _evidence:

evidence
========

.. raw:: html

  <br>


the medication used in forced treatements in the netherlands are poison.


.. raw:: html

  <br>

.. _haldol:


(1) haldol

.. raw:: html

  <br>

https://echa.europa.eu/substance-information/-/substanceinfo/100.000.142

.. raw:: html

  <br>

.. image:: ECHAhaldol.png
    :width: 100%

.. raw:: html

  <br><br>

.. _clozapine:

(2) clozapine

.. raw:: html

  <br>

https://echa.europa.eu/substance-information/-/substanceinfo/100.024.831


.. raw:: html

  <br>


.. image:: ECHAclozapine.png
    :width: 100%


.. raw:: html

  <br><br>

.. _zyprexa:

(3) zyprexa

.. raw:: html

  <br>

https://echa.europa.eu/substance-information/-/substanceinfo/100.125.320

.. raw:: html

  <br>

.. image:: ECHAzyprexa.png
    :width: 100%

.. raw:: html

  <br><br>

.. _abilify:

(4) abilify

.. raw:: html

  <br>

https://echa.europa.eu/substance-information/-/substanceinfo/100.112.532

.. raw:: html

  <br>

.. image:: ECHAabilify.png
     :width: 100%

.. raw:: html

  <br>
